@@ -24,7 +24,7 @@ using the `Lark parser library <https://github.com/lark-parser/lark>`_.
 It currently only supports Lark's native EBNF syntax, but we plan to extend
 this to support other common syntaxes such as ANTLR and :rfc:`5234` ABNF.
 Lark already `supports loading grammars
-<https://lark-parser.readthedocs.io/en/latest/nearley/>`_
+<https://lark-parser.readthedocs.io/en/latest/nearley.html>`_
 from `nearley.js <https://nearley.js.org/>`_, so you may not have to write
 your own at all.
 
@@ -205,7 +205,7 @@ def from_lark(
 
     ``grammar`` must be a ``Lark`` object, which wraps an EBNF specification.
     The Lark EBNF grammar reference can be found
-    `here <https://lark-parser.readthedocs.io/en/latest/grammar/>`_.
+    `here <https://lark-parser.readthedocs.io/en/latest/grammar.html>`_.
 
     ``from_lark`` will automatically generate strings matching the
     nonterminal ``start`` symbol in the grammar, which was supplied as an
